import os
from unittest.mock import patch, mock_open

from casa_envoy.palaver import CalibrationLauncher, check_calibratable


class TestCalibrationLauncher:

    def test_run(self):
        with patch("subprocess.Popen") as sp:
            CalibrationLauncher("test/PPR.xml", "test/test.json").run()
            sp.call_count == 1

    def test_setup_environment(self):
        parameters = {"useCasa": False,
                      "homeForReprocessing": "/home/casa/packages/pipeline/current",
                      "rootDirectory": "/tmp/workspaces_tmp/"}
        CalibrationLauncher("PPR.xml", "test.json").setup_environment(parameters=parameters)
        assert os.environ.get('SCIPIPE_ROOTDIR') == parameters["rootDirectory"]
        assert os.environ.get('CASA_HOME') == parameters["homeForReprocessing"]
        assert os.environ.get('PPR_FILENAME') == "PPR.xml"

    def test_check_logs(self):
        with patch("builtins.open", mock_open()) as o:
            CalibrationLauncher("PPR.xml", "test.json").check_logs()
            o.call_count == 1


def test_check_calibratable():
    check = check_calibratable("test/test.json")
    assert check == True
