""" Tests for fetch retryer """


import json
from unittest.mock import patch

# pylint: disable=E0401

import pytest
from datafetcher.errors import NGASServiceErrorException
from datafetcher.locations_report import NgasFileSchema, NgasTarget
from datafetcher.ngas_retriever import NgasRetriever
from datafetcher.utilities import RetrievalMode, MAX_TRIES

CAL_SUBDIR_AND_REL_PATH = "18B-265_2019_12_10_T00_00_59.203.tar"

SERVER_DICT = {
    "server": "nmngas_bogus.aoc.nrao.edu:7777",
    "location": "DSOC",
    "cluster": "DSOC",
}

FILE_DICT = {
    "ngas_file_id": "uid____EVLA_calibration_d20461ec-b0ad-44fe-86ad-a25b7a97e4c6.tar",
    "subdirectory": CAL_SUBDIR_AND_REL_PATH,
    "relative_path": CAL_SUBDIR_AND_REL_PATH,
    "checksum": "722663767",
    "checksum_type": "ngamsGenCrc32",
    "version": 1,
    "size": 27668480,
    "server": {
        "server": "nmngas_bogus.aoc.nrao.edu:7777",
        "location": "DSOC",
        "cluster": "DSOC",
    },
}


def test_copying_retries():
    """
    Retryer should kick in when direct-copy request fails.

    :return:
    """

    schema = NgasFileSchema()
    json_str = json.dumps(FILE_DICT)
    ngas_file = schema.loads(json_str)
    ngas_target = NgasTarget(ngas_file, "docker")
    ngas_target.retrieve_method = RetrievalMode.COPY

    with patch("time.sleep"):
        retriever = NgasRetriever([ngas_target], force_overwrite=False)
        with pytest.raises(NGASServiceErrorException):
            num_tries = retriever.retrieve()
            assert num_tries == MAX_TRIES


def test_streaming_retries():
    """
    Make sure retryer kicks in when a streaming request fails.

    :return:
    """

    schema = NgasFileSchema()
    json_str = json.dumps(FILE_DICT)
    ngas_file = schema.loads(json_str)
    ngas_target = NgasTarget(ngas_file, "docker")
    ngas_target.retrieve_method = RetrievalMode.STREAM

    with patch("time.sleep"):
        retriever = NgasRetriever([ngas_target], force_overwrite=False)
        with pytest.raises(NGASServiceErrorException):
            num_tries = retriever.retrieve()
            assert num_tries == MAX_TRIES
